@@ -34,7 +34,7 @@ class TestAuth(base.BaseTestCase):
 
         self.CONF.config(auth_protocol="http",
                          auth_version="v2.0",
-                         auth_uri=None,
+                         www_authenticate_uri=None,
                          group=auth.OPT_GROUP_NAME)
         self.CONF.config(enable_authentication=True)
         result = auth.install(self.app, self.CONF.conf)
@@ -43,7 +43,7 @@ class TestAuth(base.BaseTestCase):
     def test_check_auth_option_disabled(self, mock_auth):
         self.CONF.config(auth_protocol="http",
                          auth_version="v2.0",
-                         auth_uri=None,
+                         www_authenticate_uri=None,
                          group=auth.OPT_GROUP_NAME)
         self.CONF.config(enable_authentication=False)
         result = auth.install(self.app, self.CONF.conf)
